@@ -4,6 +4,10 @@ getEventData <- function(phy, eventdata, burnin=0, nsamples = NULL, verbose=FALS
 		stop("Invalid 'type' specification. Should be 'diversification' or 'trait'");
 	}
 	
+	if (class(phy) == 'character') {
+		phy <- read.tree(phy);
+	}
+	
 	phy$node.label <- NULL;
 	
 	if (any(is.null(c(phy$begin, phy$end)))) {
